@@ -11,6 +11,7 @@ import os
 import re
 from functools import cmp_to_key
 from typing import Iterable, Optional, Tuple
+
 from tqdm import tqdm
 
 from .utils import sample_md5
@@ -211,7 +212,6 @@ def detect_profile(
                 or f.endswith(".bin")
             ]
             for idx, f in enumerate(tqdm(files, desc=root)):
-
                 _r = parse_map_fname(f)
                 if _r:
                     src, dst, ver, idx = _r
@@ -283,10 +283,17 @@ def detect_profile(
             v["shards"] = _ls
             _ls_objs[k] = v
 
-    # load the preset profile
-    with open(preset_path, "r") as f:
-        res = json.load(f)
+    # quirk for da* servers
+    # follow symlinks to avoid the overhead of NFS
+    def _resolve_path(file_path: str) -> str:
+        _resolved = os.path.realpath(file_path)
+        if file_path != _resolved and re.match(r"^/da[0-9]+", _resolved):
+            _logger.warning(f"Resolve {file_path} to {_resolved}")
+            return _resolved
+        return file_path
 
+    # transform to v2
+    _total_files = 0
     for l_maps in _ls_maps.values():
         for _map in l_maps:
             # iterate over shards
@@ -296,22 +303,24 @@ def detect_profile(
                     continue
                 _new_shards.append(
                     {
-                        "path": shard_path,
+                        "path": _resolve_path(shard_path),
                         "size": os.path.getsize(shard_path),
-                        "digest": sample_md5(shard_path) if with_digest else None,
+                        "digest": None,
                     }
                 )
             _map["shards"] = _new_shards
+            _total_files += len(_new_shards)
 
             # iterate over larges
             _new_larges = {}
             for hash, large_path in _map["larges"].items():
                 _new_larges[hash] = {
-                    "path": large_path,
+                    "path": _resolve_path(large_path),
                     "size": os.path.getsize(large_path),
-                    "digest": sample_md5(large_path) if with_digest else None,
+                    "digest": None,
                 }
             _map["larges"] = _new_larges
+            _total_files += len(_new_larges)
 
     for obj_name, obj in _ls_objs.items():
         _new_shards = []
@@ -320,12 +329,13 @@ def detect_profile(
                 continue
             _new_shards.append(
                 {
-                    "path": shard_path,
+                    "path": _resolve_path(shard_path),
                     "size": os.path.getsize(shard_path),
-                    "digest": sample_md5(shard_path) if with_digest else None,
+                    "digest": None,
                 }
             )
         obj["shards"] = _new_shards
+        _total_files += len(_new_shards)
 
         # aliases
         if obj_name == "tree.tch":
@@ -335,6 +345,30 @@ def detect_profile(
         elif obj_name == "sha1.blob.tch":
             obj["alias"] = "blob"
 
+    if with_digest:
+        with tqdm(total=_total_files, desc="Calculating digests") as pbar:
+            for l_maps in _ls_maps.values():
+                for _map in l_maps:
+                    for shard in _map["shards"]:
+                        if shard is None:
+                            continue
+                        shard["digest"] = sample_md5(shard["path"])
+                        pbar.update(1)
+                    for large in _map["larges"].values():
+                        large["digest"] = sample_md5(large["path"])
+                        pbar.update(1)
+
+            for obj in _ls_objs.values():
+                for shard in obj["shards"]:
+                    if shard is None:
+                        continue
+                    shard["digest"] = sample_md5(shard["path"])
+                    pbar.update(1)
+
+    # load the preset profile
+    with open(preset_path, "r") as f:
+        res = json.load(f)
+
     res["maps"] = _ls_maps
     res["objects"] = _ls_objs
     return res
